@@ -1,4 +1,4 @@
-bayesmbc<-function(G,Z,prior,Z.K.ref=NULL,samplesize=2000,interval=10,burnin=500,verbose=FALSE){
+bayesmbc<-function(G,Z,prior,Z.K.ref=NULL,sample.size=2000,interval=10,burnin=500,verbose=FALSE){
   start<-find.clusters(G,Z)
   state<-start<-with(start,list(Z=Z,
                                 Z.mean=Z.mean,
@@ -8,17 +8,17 @@ bayesmbc<-function(G,Z,prior,Z.K.ref=NULL,samplesize=2000,interval=10,burnin=500
                      )
   if(verbose>1) cat("Running MBC MCMC... ")
   state<-bayesmbc.MCMC.C(G,start,prior,
-                         samplesize=1,interval=burnin)$samples[[1]]
+                         sample.size=1,interval=burnin)$sample[[1]]
   state$Z<-Z
-  mcmc.out<-bayesmbc.MCMC.C(G,state,prior,samplesize,interval)
+  mcmc.out<-bayesmbc.MCMC.C(G,state,prior,sample.size,interval)
   if(verbose>1) cat("Finished.\n")
 
   if(verbose>1) cat("Running label switching... ")
   Q.start <- switch.Q.K(if(is.null(Z.K.ref)) start$Z.K else Z.K.ref,G)
-  mcmc.out$samples<-klswitch.C(Q.start,mcmc.out$samples,Z,verbose=verbose)
+  mcmc.out$sample<-klswitch.C(Q.start,mcmc.out$sample,Z,verbose=verbose)
   if(verbose>1) cat("Finished.\n")
   
-  mcmc.out$pmean<-with(mcmc.out$samples,
+  mcmc.out$pmean<-with(mcmc.out$sample,
                        list(Z.mean=apply(Z.mean,2:3,mean),
                             Z.var=apply(Z.var,2,mean),
                             Z.K=apply(Z.K,2,function(x)which.max(tabulate(x,G))),
