@@ -1,21 +1,24 @@
-summary.ergmm <- function (object, point.est=c("pmean","mkl"), quantiles=c(.025,.975),se=TRUE,...)
+summary.ergmm <- function (object, point.est=c("pmean","mkl"), quantiles=c(.025,.975),se=FALSE,...)
 {
   extraneous.argcheck(...)
   ## Just for convenience.
-  samples<-object$samples
+  sample<-object$sample
   model<-object$model
   control<-object$control
   d<-model$d
   p<-model$p
   G<-model$G
   n<-network.size(model$Yg)
-  samplesize<-control$samplesize
+  sample.size<-control$sample.size
   
 
   summ<-list(ergmm=object,model=model)
 
   ## Compute the two-stage MLE point estimates.
   if("mle" %in% point.est){
+    if(is.null(object$mle)){
+      stop("MLE was not computed for this fit.")
+    }
     if(is.null(object$mle$cov)){
       if(se){
         ## Refit the MLE (mostly for the Hessian)
@@ -49,7 +52,7 @@ summary.ergmm <- function (object, point.est=c("pmean","mkl"), quantiles=c(.025,
         colnames(coef.table)<-c("Estimate",if(se) "Std. Error",if(se) "z value",if(se) "Pr(>|z|)")
         mle$coef.table<-coef.table
       }
-      mle$llk.bic<- -2*mle$llk + (p+n*d )*log(sum(network.size(model$Yg)))
+      mle$llk.bic<- -2*mle$llk + (p+n*d)*log(sum(network.size(model$Yg)))
       if(G>0){
         mle<-c(mle,find.clusters(G,mle$Z))
         mle$mbc.bic<- -bic(if(d==1) "V" else "VII",mle$mbc.llk,n,d,G)
@@ -64,32 +67,35 @@ summary.ergmm <- function (object, point.est=c("pmean","mkl"), quantiles=c(.025,
 
   ## Compute the posterior mean point estimates.
   if("pmean" %in% point.est){
+    if(is.null(object$sample)){
+      stop("MCMC was not was not run for this fit.")
+    }
     if(is.null(object$pmean)){
       pmean<-list()
-      for(name in names(samples)){
-        if(is.null(samples[[name]])) next
-        name.dim<-length(dim(samples[[name]]))
+      for(name in names(sample)){
+        if(is.null(sample[[name]])) next
+        name.dim<-length(dim(sample[[name]]))
         pmean[[name]]<-{
-          if(name.dim<2) mean(samples[[name]])
-          else if(name.dim==2) apply(samples[[name]],2,mean)
-          else if(name.dim==3) apply(samples[[name]],2:3,mean)
+          if(name.dim<2) mean(sample[[name]])
+          else if(name.dim==2) apply(sample[[name]],2,mean)
+          else if(name.dim==3) apply(sample[[name]],2:3,mean)
         }
       }
       if(G>0){
-        pmean$Z.pZK<-t(apply(samples$Z.K,2,tabulate,G))/samplesize
+        pmean$Z.pZK<-t(apply(sample$Z.K,2,tabulate,G))/sample.size
         pmean$Z.K<-apply(pmean$Z.pZK,1,which.max)
       }
     
-      beta.cov<-cov(samples$beta)
+      beta.cov<-cov(sample$beta)
       colnames(beta.cov) <- rownames(beta.cov) <- model$coef.names
       
       pmean$cov<-beta.cov
       pmean$cor<-cov2cor(beta.cov)
       
-      beta.q0<-apply(samples$beta,2,function(x) mean(x<=0))
+      beta.q0<-apply(sample$beta,2,function(x) mean(x<=0))
       
       coef.table<-data.frame(pmean$beta,
-                           t(apply(samples$beta,2,function(x)quantile(x,quantiles))),
+                           t(apply(sample$beta,2,function(x)quantile(x,quantiles))),
                            beta.q0,
                            row.names=model$coef.names)
       colnames(coef.table)<-c("Estimate",paste(quantiles*100,"%",sep=""),"Quantile of 0")
@@ -100,6 +106,9 @@ summary.ergmm <- function (object, point.est=c("pmean","mkl"), quantiles=c(.025,
   }
   ## Compute the MKL point estimates.
   if("mkl" %in% point.est){
+    if(is.null(object$mkl)){
+      stop("MKL was not produced for this fit.")
+    }
     mkl<-summ$mkl<-object$mkl
     coef.table<-data.frame(mkl$beta,
                            row.names=model$coef.names)
@@ -108,6 +117,9 @@ summary.ergmm <- function (object, point.est=c("pmean","mkl"), quantiles=c(.025,
   }
 
   if("pmode" %in% point.est){
+    if(is.null(object$pmode)){
+      stop("Conditional posterior mode was not computed for this fit.")
+    }
     summ$pmode<-object$pmode
   }
 
@@ -118,7 +130,7 @@ summary.ergmm <- function (object, point.est=c("pmean","mkl"), quantiles=c(.025,
 print.summary.ergmm<-function(x,...){
   ## For convenience
   model<-x$model
-  control<-x$control
+  control<-x$ergmm$control
   
   cat("\n==========================\n")
   cat("Summary of model fit\n")
@@ -133,7 +145,7 @@ print.summary.ergmm<-function(x,...){
   
   digits = max(3, getOption("digits") - 3)
   
-  cat ("MCMC sample of size ", control$samplesize, ", samples are ",
+  cat ("MCMC sample of size ", control$sample.size, ", draws are ",
        control$interval," iterations apart, after burnin of ",control$burnin, " iterations.\n",sep="")
        
   if(!is.null(x$pmean)){
@@ -154,11 +166,7 @@ print.summary.ergmm<-function(x,...){
     }
     cat("\n")
   }
-  if(!is.null(x$pmean)){
-    cat("Covariate coefficients posterior mean:\n")
-    print(x$pmean$coef.table)
-    cat("\n\n")
-  }
+
   if(!is.null(x$mkl)){
     cat("Covariate coefficients MKL:\n")
     print(x$mkl$coef.table)
