@@ -7,7 +7,7 @@
 #define LOG_ILOGIT(Y,eta,i,j) (Y[i][j]*eta[i][j]-log(1+exp(eta[i][j])))
 #define IS_OBSERVABLE(obs_ties,i,j) (obs_ties ? obs_ties[i][j] : i!=j)
 
-R_INLINE double ERGMM_MCMC_etaij(ERGMM_MCMC_Model *model, ERGMM_MCMC_Par *par,unsigned int i,unsigned int j);
+/*R_INLINE*/ double ERGMM_MCMC_etaij(ERGMM_MCMC_Model *model, ERGMM_MCMC_Par *par,unsigned int i,unsigned int j);
 double ERGMM_MCMC_lp_Y(ERGMM_MCMC_Model *model, ERGMM_MCMC_Par *par, unsigned int own_lpedge);
 double ERGMM_MCMC_lp_Y_diff(ERGMM_MCMC_Model *model, ERGMM_MCMC_MCMCState *cur);
 double ERGMM_MCMC_logp_Z(ERGMM_MCMC_Model *model, ERGMM_MCMC_Par *par);
