@@ -8,10 +8,8 @@ void pairwise_dist(double **A,unsigned int n,unsigned int dim, double **dist);
 void update_dist(double **A,unsigned int i, unsigned int n, unsigned int dim, double **dist);
 double *latentpos_average(double **A, unsigned int n, unsigned int m, double *avA);
 void latentpos_translate(double **A, unsigned int n, unsigned int m, double *by);
-void randeff_translate(double *v, unsigned int n, double by);
-void add_randeff(double *effect, unsigned int n, double **eta, unsigned int is_col);
 unsigned int *runifperm(unsigned int n, unsigned int *a);
-R_INLINE void iswap(int *a, int *b);
-R_INLINE void uiswap(unsigned int *a, unsigned int *b);
+/*R_INLINE*/ void iswap(int *a, int *b);
+/*R_INLINE*/ void uiswap(unsigned int *a, unsigned int *b);
 void copy_MCMC_Par(ERGMM_MCMC_Model *model, ERGMM_MCMC_Par *source, ERGMM_MCMC_Par *dest);
 #endif
